This directory contains test scripts for the
Python package `tla`.
To run them using the package [`pytest`](
    https://pypi.org/project/pytest/):

```shell
pytest -v --continue-on-collection-errors .
```
